@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, unicode_literals, division
 import atexit
 from .meta import version as __version__, description as __doc__
 from .constants import *
